<?php
/**
 * Sourcewp Theme Customizer
 *
 * @package adle
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function adle_customize_register( $wp_customize ) {
	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->default   = '#EF4126';
}
add_action( 'customize_register', 'adle_customize_register' );

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function adle_customize_preview_js() {
	wp_enqueue_script( 'adle_customizer', get_template_directory_uri() . '/inc/js/customizer.js', array( 'customize-preview' ), '20150423', true );
}
add_action( 'customize_preview_init', 'adle_customize_preview_js' );

/**
 * Options for Sourcewp Theme Customizer.
 */
function adle_customizer( $wp_customize ) {

    /* Main option Settings Panel */
    $wp_customize->add_panel('adle_main_options', array(
        'capability' => 'edit_theme_options',
        'theme_supports' => '',
        'title' => __('Sourcewp Options', 'adle'),
        'description' => __('Panel to update adle theme options', 'adle'), // Include html tags such as <p>.
        'priority' => 10 // Mixed with top-level-section hierarchy.
    ));
           
            // Layout options
            global $site_layout;
            $wp_customize->add_setting('adle[site_layout]', array(
                 'default' => 'side-pull-left',
                 'type' => 'option',
                 'sanitize_callback' => 'adle_sanitize_layout'
            ));
            $wp_customize->add_control('adle[site_layout]', array(
                 'label' => __('Website Layout Options', 'adle'),
                 'section' => 'adle_layout_options',
                 'type'    => 'select',
                 'description' => __('Choose between different layout options to be used as default', 'adle'),
                 'choices'    => $site_layout
            ));

            $wp_customize->add_setting('adle[element_color]', array(
                'default' => '',
                'type'  => 'option',
                'sanitize_callback' => 'adle_sanitize_hexcolor'
            ));
            $wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'adle[element_color]', array(
                'label' => __('Element Color', 'adle'),
                'description'   => __('Default used if no color is selected','adle'),
                'section' => 'adle_layout_options',
                'settings' => 'adle[element_color]',
            )));

            $wp_customize->add_setting('adle[element_color_hover]', array(
                'default' => '',
                'type'  => 'option',
                'sanitize_callback' => 'adle_sanitize_hexcolor'
            ));
            $wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'adle[element_color_hover]', array(
                'label' => __('Element color on hover', 'adle'),
                'description'   => __('Default used if no color is selected','adle'),
                'section' => 'adle_layout_options',
                'settings' => 'adle[element_color_hover]',
            )));


        /* Sourcewp Typography Options */
        $wp_customize->add_section('adle_typography_options', array(
            'title' => __('Typography', 'adle'),
            'priority' => 31,
            'panel' => 'adle_main_options'
        ));
            global $typography_defaults;

            // Typography Options
            global $typography_options;
            $wp_customize->add_setting('adle[main_body_typography][size]', array(
                'default' => $typography_defaults['size'],
                'type' => 'option',
                'sanitize_callback' => 'adle_sanitize_typo_size'
            ));
            $wp_customize->add_control('adle[main_body_typography][size]', array(
                'label' => __('Main Body Text', 'adle'),
                'description' => __('Used in p tags', 'adle'),
                'section' => 'adle_typography_options',
                'type'    => 'select',
                'choices'    => $typography_options['sizes']
            ));
            $wp_customize->add_setting('adle[main_body_typography][face]', array(
                'default' => $typography_defaults['face'],
                'type' => 'option',
                'sanitize_callback' => 'adle_sanitize_typo_face'
            ));
            $wp_customize->add_control('adle[main_body_typography][face]', array(
                'section' => 'adle_typography_options',
                'type'    => 'select',
                'choices'    => $typography_options['faces']
            ));
            $wp_customize->add_setting('adle[main_body_typography][style]', array(
                'default' => $typography_defaults['style'],
                'type' => 'option',
                'sanitize_callback' => 'adle_sanitize_typo_style'
            ));
            $wp_customize->add_control('adle[main_body_typography][style]', array(
                'section' => 'adle_typography_options',
                'type'    => 'select',
                'choices'    => $typography_options['styles']
            ));
            $wp_customize->add_setting('adle[main_body_typography][color]', array(
                'default' => $typography_defaults['color'],
                'type'  => 'option',
                'sanitize_callback' => 'adle_sanitize_hexcolor'
            ));
            $wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'adle[main_body_typography][color]', array(
                'section' => 'adle_typography_options',
            )));

            $wp_customize->add_setting('adle[heading_color]', array(
                'default' => '',
                'type'  => 'option',
                'sanitize_callback' => 'adle_sanitize_hexcolor'
            ));
            $wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'adle[heading_color]', array(
                'label' => __('Heading Color', 'adle'),
                'description'   => __('Color for all headings (h1-h6)','adle'),
                'section' => 'adle_typography_options',
            )));
            $wp_customize->add_setting('adle[link_color]', array(
                'default' => '',
                'type'  => 'option',
                'sanitize_callback' => 'adle_sanitize_hexcolor'
            ));
            $wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'adle[link_color]', array(
                'label' => __('Link Color', 'adle'),
                'description'   => __('Default used if no color is selected','adle'),
                'section' => 'adle_typography_options',
            )));
            $wp_customize->add_setting('adle[link_hover_color]', array(
                'default' => '',
                'type'  => 'option',
                'sanitize_callback' => 'adle_sanitize_hexcolor'
            ));
            $wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'adle[link_hover_color]', array(
                'label' => __('Link:hover Color', 'adle'),
                'description'   => __('Default used if no color is selected','adle'),
                'section' => 'adle_typography_options',
            )));

        /* Sourcewp Header Options */
        $wp_customize->add_section('adle_header_options', array(
            'title' => __('Header', 'adle'),
            'priority' => 31,
            'panel' => 'adle_main_options'
        ));
            $wp_customize->add_setting('adle[top_nav_bg_color]', array(
                'default' => '',
                'type'  => 'option',
                'sanitize_callback' => 'adle_sanitize_hexcolor'
            ));
            $wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'adle[top_nav_bg_color]', array(
                'label' => __('Top nav background color', 'adle'),
                'description'   => __('Default used if no color is selected','adle'),
                'section' => 'adle_header_options',
            )));
            $wp_customize->add_setting('adle[top_nav_link_color]', array(
                'default' => '',
                'type'  => 'option',
                'sanitize_callback' => 'adle_sanitize_hexcolor'
            ));
            $wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'adle[top_nav_link_color]', array(
                'label' => __('Top nav item color', 'adle'),
                'description'   => __('Link color','adle'),
                'section' => 'adle_header_options',
            )));

            $wp_customize->add_setting('adle[top_nav_dropdown_bg]', array(
                'default' => '',
                'type'  => 'option',
                'sanitize_callback' => 'adle_sanitize_hexcolor'
            ));
            $wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'adle[top_nav_dropdown_bg]', array(
                'label' => __('Top nav dropdown background color', 'adle'),
                'description'   => __('Background of dropdown item hover color','adle'),
                'section' => 'adle_header_options',
            )));

            $wp_customize->add_setting('adle[top_nav_dropdown_item]', array(
                'default' => '',
                'type'  => 'option',
                'sanitize_callback' => 'adle_sanitize_hexcolor'
            ));
            $wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'adle[top_nav_dropdown_item]', array(
                'label' => __('Top nav dropdown item color', 'adle'),
                'description'   => __('Dropdown item color','adle'),
                'section' => 'adle_header_options',
            )));

        /* Sourcewp Footer Options */
        $wp_customize->add_section('adle_footer_options', array(
            'title' => __('Footer', 'adle'),
            'priority' => 31,
            'panel' => 'adle_main_options'
        ));
            $wp_customize->add_setting('adle[footer_widget_bg_color]', array(
                'default' => '',
                'type'  => 'option',
                'sanitize_callback' => 'adle_sanitize_hexcolor'
            ));
            $wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'adle[footer_widget_bg_color]', array(
                'label' => __('Footer widget area background color', 'adle'),
                'section' => 'adle_footer_options',
            )));

            $wp_customize->add_setting('adle[footer_bg_color]', array(
                'default' => '',
                'type'  => 'option',
                'sanitize_callback' => 'adle_sanitize_hexcolor'
            ));
            $wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'adle[footer_bg_color]', array(
                'label' => __('Footer background color', 'adle'),
                'section' => 'adle_footer_options',
            )));

            $wp_customize->add_setting('adle[footer_text_color]', array(
                'default' => '',
                'type'  => 'option',
                'sanitize_callback' => 'adle_sanitize_hexcolor'
            ));
            $wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'adle[footer_text_color]', array(
                'label' => __('Footer text color', 'adle'),
                'section' => 'adle_footer_options',
            )));

            $wp_customize->add_setting('adle[footer_link_color]', array(
                'default' => '',
                'type'  => 'option',
                'sanitize_callback' => 'adle_sanitize_hexcolor'
            ));
            $wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'adle[footer_link_color]', array(
                'label' => __('Footer link color', 'adle'),
                'section' => 'adle_footer_options',
            )));

            $wp_customize->add_setting('adle[custom_footer_text]', array(
                'default' => '',
                'type' => 'option',
                'sanitize_callback' => 'adle_sanitize_strip_slashes'
            ));
            $wp_customize->add_control('adle[custom_footer_text]', array(
                'label' => __('Footer information', 'adle'),
                'description' => sprintf(__('Copyright text in footer', 'adle')),
                'section' => 'adle_footer_options',
                'type' => 'textarea'
            ));

        /* Sourcewp Other Options */
        $wp_customize->add_section('adle_other_options', array(
            'title' => __('Other', 'adle'),
            'priority' => 31,
            'panel' => 'adle_main_options'
        ));
            $wp_customize->add_setting('adle[custom_css]', array(
                'default' => '',
                'type' => 'option',
                'sanitize_callback' => 'adle_sanitize_strip_slashes'
            ));
            $wp_customize->add_control('adle[custom_css]', array(
                'label' => __('Custom CSS', 'adle'),
                'description' => sprintf(__('Additional CSS', 'adle')),
                'section' => 'adle_other_options',
                'type' => 'textarea'
            ));

        $wp_customize->add_section('adle_important_links', array(
            'priority' => 5,
            'title' => __('Support and Documentation', 'adle')
        ));
            $wp_customize->add_setting('adle[imp_links]', array(
              'sanitize_callback' => 'esc_url_raw'
            ));
            $wp_customize->add_control(
            new Sourcewp_Important_Links(
            $wp_customize,
                'adle[imp_links]', array(
                'section' => 'adle_important_links',
                'type' => 'adle-important-links'
            )));

}
add_action( 'customize_register', 'adle_customizer' );



/**
 * Sanitize checkbox for WordPress customizer
 */
function adle_sanitize_checkbox( $input ) {
    if ( $input == 1 ) {
        return 1;
    } else {
        return '';
    }
}
/**
 * Adds sanitization callback function: colors
 * @package Sourcewp
 */
function adle_sanitize_hexcolor($color) {
    if ($unhashed = sanitize_hex_color_no_hash($color))
        return '#' . $unhashed;
    return $color;
}

/**
 * Adds sanitization callback function: Nohtml
 * @package Sourcewp
 */
function adle_sanitize_nohtml($input) {
    return wp_filter_nohtml_kses($input);
}

/**
 * Adds sanitization callback function: Number
 * @package Sourcewp
 */
function adle_sanitize_number($input) {
    if ( isset( $input ) && is_numeric( $input ) ) {
        return $input;
    }
}

/**
 * Adds sanitization callback function: Strip Slashes
 * @package Sourcewp
 */
function adle_sanitize_strip_slashes($input) {
    return wp_kses_stripslashes($input);
}

/**
 * Adds sanitization callback function: Slider Category
 * @package Sourcewp
 */
function adle_sanitize_slidecat( $input ) {
    global $options_categories;
    if ( array_key_exists( $input, $options_categories ) ) {
        return $input;
    } else {
        return '';
    }
}

/**
 * Adds sanitization callback function: Sidebar Layout
 * @package Sourcewp
 */
function adle_sanitize_layout( $input ) {
    global $site_layout;
    if ( array_key_exists( $input, $site_layout ) ) {
        return $input;
    } else {
        return '';
    }
}

/**
 * Adds sanitization callback function: Typography Size
 * @package Sourcewp
 */
function adle_sanitize_typo_size( $input ) {
    global $typography_options,$typography_defaults;
    if ( array_key_exists( $input, $typography_options['sizes'] ) ) {
        return $input;
    } else {
        return $typography_defaults['size'];
    }
}
/**
 * Adds sanitization callback function: Typography Face
 * @package Sourcewp
 */
function adle_sanitize_typo_face( $input ) {
    global $typography_options,$typography_defaults;
    if ( array_key_exists( $input, $typography_options['faces'] ) ) {
        return $input;
    } else {
        return $typography_defaults['face'];
    }
}
/**
 * Adds sanitization callback function: Typography Style
 * @package Sourcewp
 */
function adle_sanitize_typo_style( $input ) {
    global $typography_options,$typography_defaults;
    if ( array_key_exists( $input, $typography_options['styles'] ) ) {
        return $input;
    } else {
        return $typography_defaults['style'];
    }
}

/**
 * Add CSS for custom controls
 */
function adle_customizer_custom_control_css() {
	?>
    <style>
        #customize-control-adle-main_body_typography-size select, #customize-control-adle-main_body_typography-face select,#customize-control-adle-main_body_typography-style select { width: 60%; }
    </style><?php
}
add_action( 'customize_controls_print_styles', 'adle_customizer_custom_control_css' );

if ( ! class_exists( 'WP_Customize_Control' ) )
    return NULL;
/**
 * Class to create a Sourcewp important links
 */
class Sourcewp_Important_Links extends WP_Customize_Control {

   public $type = "adle-important-links";

   public function render_content() {?>
         <!-- Twitter -->
        <script>!function(d,s,id){var js,fjs=d.getElementsByTagName(s)[0],p=/^http:/.test(d.location)?'http':'https';if(!d.getElementById(id)){js=d.createElement(s);js.id=id;js.src=p+'://platform.twitter.com/widgets.js';fjs.parentNode.insertBefore(js,fjs);}}(document, 'script', 'twitter-wjs');</script>

        <!-- Facebook -->
        <div id="fb-root"></div>
        <script>
            (function(d, s, id) {
            var js, fjs = d.getElementsByTagName(s)[0];
            if (d.getElementById(id)) return;
            js = d.createElement(s); js.id = id;
            js.src = "//connect.facebook.net/en_US/all.js#xfbml=1&appId=328285627269392";
            fjs.parentNode.insertBefore(js, fjs);
            }(document, 'script', 'facebook-jssdk'));
        </script>

        <div class="inside">
            <div id="social-share">
              <div class="fb-like" data-href="<?php echo esc_url( 'https://www.facebook.com/adle' ); ?>" data-send="false" data-layout="button_count" data-width="90" data-show-faces="true"></div>
              <div class="tw-follow" ><a href="https://twitter.com/adle" class="twitter-follow-button" data-show-count="false">Follow @adle</a></div>
            </div>
            <p><b><a href="<?php echo esc_url( 'http://adle.com/wp/support/adle' ); ?>"><?php esc_html_e('Sourcewp Documentation','adle'); ?></a></b></p>
            <p><?php _e('The best way to contact us with <b>support questions</b> and <b>bug reports</b> is via','adle') ?> <a href="<?php echo esc_url( 'http://adle.com/wp/forums' ); ?>"><?php esc_html_e('Sourcewp support forum','adle') ?></a>.</p>
            <p><?php esc_html_e('If you like this theme, I\'d appreciate any of the following:','adle') ?></p>
            <ul>
              <li><a class="button" href="<?php echo esc_url( 'http://wordpress.org/support/view/theme-reviews/adle?filter=5' ); ?>" title="<?php esc_attr_e('Rate this Theme', 'adle'); ?>" target="_blank"><?php printf(esc_html__('Rate this Theme','adle')); ?></a></li>
              <li><a class="button" href="<?php echo esc_url( 'http://www.facebook.com/adle' ); ?>" title="Like Sourcewp on Facebook" target="_blank"><?php printf(esc_html__('Like on Facebook','adle')); ?></a></li>
              <li><a class="button" href="<?php echo esc_url( 'http://twitter.com/adle/' ); ?>" title="Follow Colrolib on Twitter" target="_blank"><?php printf(esc_html__('Follow on Twitter','adle')); ?></a></li>
            </ul>
        </div><?php
   }

}

/*
 * Custom Scripts
 */
add_action( 'customize_controls_print_footer_scripts', 'customizer_custom_scripts' );

function customizer_custom_scripts() { ?>
<script type="text/javascript">
    jQuery(document).ready(function() {
        /* This one shows/hides the an option when a checkbox is clicked. */
        jQuery('#customize-control-adle-adle_slide_categories, #customize-control-adle-adle_slide_number').hide();
        jQuery('#customize-control-adle-adle_slider_checkbox input').click(function() {
            jQuery('#customize-control-adle-adle_slide_categories, #customize-control-adle-adle_slide_number').fadeToggle(400);
        });

        if (jQuery('#customize-control-adle-adle_slider_checkbox input:checked').val() !== undefined) {
            jQuery('#customize-control-adle-adle_slide_categories, #customize-control-adle-adle_slide_number').show();
        }
    });
</script>
<style>
    li#accordion-section-adle_important_links h3.accordion-section-title, li#accordion-section-adle_important_links h3.accordion-section-title:focus { background-color: #00cc00 !important; color: #fff !important; }
    li#accordion-section-adle_important_links h3.accordion-section-title:hover { background-color: #00b200 !important; color: #fff !important; }
    li#accordion-section-adle_important_links h3.accordion-section-title:after { color: #fff !important; }
</style>
<?php
}
